==> pointpos_api-0.0.13.tar.gz: lib/api/sales_type_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/sales_type.dart';

part 'sales_type_api.jretro.dart';

@GenApiClient()
class SalesTypeApi extends ApiClient with _$SalesTypeApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    SalesTypeApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Salestype
    ///
    /// Create Salestype
    @PostReq(path: "/sales-type", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<SalesType> createSalestype(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() SalesType body
        ) {
        return super.createSalestype(
        
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Salestype By ID
    ///
    /// Delete Salestype By ID
    @DeleteReq(path: "/sales-type/:name", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteSalestypeByID(
            @PathParam("name") String name
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.deleteSalestypeByID(
        name
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Get Salestype List
    ///
    /// Get Salestype  List
    @GetReq(path: "/sales-type", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<SalesType>> findSalestype(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findSalestype(
        
        authorization, 
        
        xAPIKey
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Salestype By ID
    ///
    /// Get Salestype By ID
    @GetReq(path: "/sales-type/:name", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<SalesType> getSalestypeByID(
            @PathParam("name") String name
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.getSalestypeByID(
        name
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Update Salestype By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/sales-type/:name", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<SalesType> updateSalestypeByID(
            @PathParam("name") String name
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() SalesType body
        ) {
        return super.updateSalestypeByID(
        name
        ,
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }


}

==> pointpos_api-0.0.16.tar.gz: lib/api/sales_type_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/sales_type.dart';

part 'sales_type_api.jretro.dart';

@GenApiClient()
class SalesTypeApi extends ApiClient with _$SalesTypeApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    SalesTypeApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Salestype
    ///
    /// Create Salestype
    @PostReq(path: "/sales-type", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<SalesType> createSalestype(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() SalesType body
        ) {
        return super.createSalestype(
        
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Salestype By ID
    ///
    /// Delete Salestype By ID
    @DeleteReq(path: "/sales-type/:name", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteSalestypeByID(
            @PathParam("name") String name
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.deleteSalestypeByID(
        name
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Get Salestype List
    ///
    /// Get Salestype  List
    @GetReq(path: "/sales-type", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<SalesType>> findSalestype(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findSalestype(
        
        authorization, 
        
        xAPIKey, 
        
        xPin
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Salestype By ID
    ///
    /// Get Salestype By ID
    @GetReq(path: "/sales-type/:name", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<SalesType> getSalestypeByID(
            @PathParam("name") String name
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.getSalestypeByID(
        name
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Update Salestype By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/sales-type/:name", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<SalesType> updateSalestypeByID(
            @PathParam("name") String name
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() SalesType body
        ) {
        return super.updateSalestypeByID(
        name
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }


}
